/******************************************************************************
 *
 * setoffset()
 *
 * This function sets the global offset variable (defined in config.h) to
 * the appropriate value for the used device.
 * I use libdnet and libpcap to determine the link layer size.
 *
 */

int setoffset(struct intf_entry *entry, pcap_t *pcap)
{
    extern int offset;
    switch (entry->intf_type)
    {
        case INTF_TYPE_ETH:
            offset=14;
            break;
        case INTF_TYPE_LOOPBACK:
            offset=4;
            break;
        case INTF_TYPE_TUN:
            offset=4;
            break;
        default:
            // try pcap
            switch (pcap_datalink(pcap))
            {
                case DLT_EN10MB: 
                    offset = 14; break; // ethernet
                case DLT_NULL:
                    offset =  0; break; // no link layer encap.
                case DLT_PPP:
                case DLT_LOOP:
                    offset =  4; break; // PPP or loopback
               case DLT_SLIP:
                    offset = 16; break; // SLIP link
            case DLT_FDDI:
                    offset = 21; break; // FDDI
            default:
                    offset = -1; // assume ethernet
            }
    }
    error(ERR_DEBUG,  "setting device offset to %d", offset);
    error(ERR_DEBUGV, "interface name: %s", entry->intf_name);
    error(ERR_DEBUGV, "interface type: %d", entry->intf_type);

    return 0;
}
